rm(list=ls()) 
library("MCMCglmm")

# Base de datos ####
Face_ped <- read.table("./Face_ped_all.txt") #pedigr
Face_data <- read.table("./Face_data_residScaled_fit.txt", sep="") #datos
Face_ped$dam <- as.factor(Face_ped$dam)
Face_ped$sire <- as.factor(Face_ped$sire)
Face_data$dam <- as.factor(Face_data$dam)
Face_data$animal <- as.factor(Face_data$animal)

# Probabilidad inicial uniforme
phen.varIdent <- diag(5) #nmero de variables 
priorMul <- list(R = list(V=phen.varIdent, nu= 1), G = list(G1 = list(V=phen.varIdent, nu= 1))) 

#modelo lineal generalizado mixto
modelmult_fit <- MCMCglmm(cbind(Talla, hijos, firstkid, lastkid, rangeFert)~trait,
                      random= ~us(trait):animal,
                      rcov= ~us(trait):units,
                      family= c("gaussian","gaussian","gaussian","gaussian", "gaussian"),
                      prior= priorMul,
                      data=Face_data,
                      nitt=150000,
                      burnin=1000,
                      thin=1000)

# guardar modelo
save(modelmult_fit, file = "./modelmult_fit.obj")
# guardar la distribucin posterior de la matriz de covarianza
write.csv(modelmult_fit$VCV, "modelmult_fitVCV.csv")
# leer la distribucin posterior de la matriz de covarianza
VCV_mult_fit <- read.csv("C:./modelmult_fitVCV.csv", sep = ",")
colnames(VCV_mult_fit) <-  gsub("trait", "", colnames(VCV_mult_fit))

# Matriz G ####
# Ecuacin 1
#proporcin de varianza gentica aditiva en la variacin fenotpica
#model1_Mat$VCV[, "animal"]/(model1_Mat$VCV[, "animal"] + model1_Mat$VCV[, "units"])
AniValues_fit <- VCV_mult_fit[,2:26] # varianza gentica aditiva
UniValues_fit <- VCV_mult_fit[,27:51] # varianza ambiental
colnames(AniValues_fit) <-  gsub(".animal", "", colnames(AniValues_fit))
colnames(UniValues_fit) <-  gsub(".units", "", colnames(UniValues_fit))
G <- AniValues_fit/(AniValues_fit+UniValues_fit)
Gmatrix_fit <- matrix(posterior.mode(G), 5,5)
traitnames <- c("Talla","n_hijos", "1er_hijo", "ult_hijo", "rango_Fer")
colnames(Gmatrix_fit) <- traitnames
rownames(Gmatrix_fit) <- traitnames

# guardar matriz G
write.table(Gmatrix, "Gmatrix_fit.txt")

