rm(list=ls()) 
library("MCMCglmm")

# Base de datos ####
Face_ped <- read.table("./Face_ped_all.txt") #pedigr
Face_data <- read.table("./Face_data_residScaled_phen.txt", sep="") #datos
Face_ped$dam <- as.factor(Face_ped$dam)
Face_ped$sire <- as.factor(Face_ped$sire)
Face_data$dam <- as.factor(Face_data$dam)
Face_data$animal <- as.factor(Face_data$animal)

# Probabilidad inicial uniforme
phen.varIdent <- diag(6) #nmero de variables
priorMul <- list(R = list(V=phen.varIdent, nu= 1), G = list(G1 = list(V=phen.varIdent, nu= 1))) 

#modelo lineal generalizado mixto
modelmult_phen <- MCMCglmm(cbind(Talla, Bigo, Bizig, GnaNa, GnaGo, Bitra)~trait,
                          random= ~us(trait):animal,
                          rcov= ~us(trait):units,
                          family= c("gaussian","gaussian","gaussian", "gaussian","gaussian", "gaussian"),
                          prior= priorMul,
                          data=Face_data,
                          nitt=150000,
                          burnin=1000,
                          thin=1000)

# guardar modelo
save(modelmult_phen, file = "./modelmult_phen.obj")
# guardar la distribucin posterior de la matriz de covarianza
write.csv(modelmult_phen$VCV, "modelmult_phenVCV.csv")
# leer la distribucin posterior de la matriz de covarianza
VCV_mult_phen <- read.csv("C:./modelmult_phenVCV.csv", sep = ",")
colnames(VCV_mult_phen) <-  gsub("trait", "", colnames(VCV_mult_phen))

# Matriz G ####
# Ecuacin 1
#proporcin de varianza gentica aditiva en la variacin fenotpica
#model1_Mat$VCV[, "animal"]/(model1_Mat$VCV[, "animal"] + model1_Mat$VCV[, "units"])
AniValues_phen <- VCV_mult_phen[,2:37] # varianza gentica aditiva
UniValues_phen <- VCV_mult_phen[,38:73] # varianza ambiental
colnames(AniValues_phen) <-  gsub(".animal", "", colnames(AniValues_phen))
colnames(UniValues_phen) <-  gsub(".units", "", colnames(UniValues_phen))
G <- AniValues_phen/(AniValues_phen+UniValues_phen)
Gmatrix_phen <- matrix(posterior.mode(G), 6,6)
traitnames <- c("Talla","Bigo", "Bizig", "GnaNa", "GnaGo", "Bitra")
colnames(Gmatrix_phen) <- traitnames
rownames(Gmatrix_phen) <- traitnames

# guardar matriz G
write.table(Gmatrix_phen, "Gmatrix_phen.txt")
