rm(list = ls())
library(reshape2)
library(ggplot2)
library(tidyr)

# datos ####
Face_data <- read.table("./Face_data_residScaled_phenTALLA.txt", sep="")
Face_data_fit <- read.table("./Face_data_residScaled_fitTALLA.txt", sep="")

# MATRIZ DE COVARIANZA ####
# Morfologa ####
# estandarizados por sexo, edad e IMC
Pmatrix_all <- cov(Face_data[,-c(7:9)])
write.table(Pmatrix_all, "Pmatrix_phen.txt") #matriz de covarianza
melted.rasgos <- melt(Pmatrix_all)
ggplot(data = melted.rasgos, aes(x=Var1, y=Var2, fill=value)) + 
      geom_tile() + scale_fill_gradient2(low = "cadetblue3", high = "dodgerblue4", mid = "white", 
                                         midpoint = 0, limit = c(-1.1,1.1), space = "Lab", name="Covarianza") +
      theme_minimal()+ theme(axis.text.x = element_text(angle = 65, vjust = 1,size = 12, hjust = 1))+ coord_fixed()+
      geom_text(aes(Var2, Var1, label = round(value, 3)), color = "black", size = 2)+
  theme(axis.title = element_blank(), 
        legend.position="none")
    


# Aptitud biolgica ####
#estandarizados por sexo, edad e IMC
colnames(Face_data_fit) <- c("Talla", "n_hijos", "1er_hijo",
                              "ult_hijo", "rango_Fer", "sire", "dam",
                              "animal")

Pmatrix_fit <- cov(Face_data_fit[,-c(6:8)])
write.table(Pmatrix_fit, "Pmatrix_fit.txt")
melted.rasgosF <- melt(Pmatrix_fit)
ggplot(data = melted.rasgosF, aes(x=Var1, y=Var2, fill=value)) + 
  geom_tile() + 
  scale_fill_gradient2(low = "cadetblue3", 
                       high = "dodgerblue4", mid = "white", 
                                     midpoint = 0, limit = c(-1.1,1.1), space = "Lab", name="Covarianza") +
  theme_minimal()+ theme(axis.text.x = element_text(angle = 65, vjust = 1,size = 12, hjust = 1))+ coord_fixed()+
  geom_text(aes(Var2, Var1, label = round(value, 3)), color = "black", size = 2) +
  theme(axis.title = element_blank())


#PCA####
# Morfologa ####
rasgos <- Face_data[,-c(7:9)]
df_all <- prcomp(rasgos, scale. = T)
df_allout <- as.data.frame(df_all$x)
df_all_r <- as.data.frame(df_all$rotation)
df_all_r$feature <- row.names(df_all$rotation)

# Aptitud biolgica ####
rasgos.f <- Face_data_fit[,-c(6:8)]
df_fit <- prcomp(rasgos.f, scale. = T)
df_fitout <- as.data.frame(df_fit$x)
df_fit_r <- as.data.frame(df_fit$rotation)
df_fit_r$feature <- row.names(df_fit$rotation)


#INTEGRACIN por eigenvalores ####
# Morfologa ####
df_eigen <- df_all$sdev^2
df_eigen <- as.data.frame(df_eigen)
colnames(df_eigen)[1] <- "eigenvalor" 
df_eigen$PC <- c("PC1", "PC2", "PC3", "PC4", "PC5","PC6")
ggplot(df_eigen, aes(x=PC, y=eigenvalor))+
  geom_point(colour = "mediumvioletred") + ylim(0, 5)

# Aptitud biolgica ####
df_eigen_fit <- df_fit$sdev^2
df_eigen_fit <- as.data.frame(df_eigen_fit)
colnames(df_eigen_fit)[1] <- "eigenvalor" 
df_eigen_fit$PC <- c("PC1", "PC2", "PC3", "PC4", "PC5")
ggplot(df_eigen_fit, aes(x=PC, y=eigenvalor))+
  geom_point(colour = "mediumvioletred") + ylim(0, 5)


#INTEGRACIN por Desviacin Estndar de los eigenvalores ####
# Morfologa ####
estDev_phen <- sd(df_eigen[,1])/sqrt(6-1) #0.64
# Aptitud biolgica ####
estDev_fit <- sd(df_eigen_fit[, 1])/sqrt(5-1) #0.58
