rm(list=ls()) 
library("MCMCglmm")

# Base de datos ####
Face_ped <- read.table("./Face_ped_all.txt") #pedigr
Face_data <- read.table("./Face_data_residScaled_fit_Mat.txt", sep="") #datos
Face_ped$dam <- as.factor(Face_ped$dam)
Face_ped$sire <- as.factor(Face_ped$sire)
Face_data$dam <- as.factor(Face_data$dam)
Face_data$animal <- as.factor(Face_data$animal)

# Probabilidad inicial uniforme
# con efecto materno (EM)
prior <- list(R = list(V=1, nu= 1), G = list(G1 = list(V=1, nu= 1), G2=list(V=1, nu=1)))
# sin efecto materno
priorA <- list(R = list(V=1, nu= 1), G = list(G1 = list(V=1, nu= 1)))

colnames(Face_data)
#modelo lineal generalizado mixto
# en caso de estimar heredabilidad 
        # random = ~ animal,
        # prior = priorA
# en caso de estimar heredabilidad + EM
        # random = ~ animal + dam,
        # prior = prior
modelMat <- MCMCglmm(rangeFert ~ 1,                  
                     random = ~ animal,# + dam,         
                     family =  "gaussian",               
                     prior = priorA,          
                     data = Face_data,                
                     nitt = 650000,                    
                     burnin = 2000,                   
                     thin = 500)                      

# guardar modelo
save(modelMat, file = "./MrangeFert.obj")
# checar el modelo
plot(modelMat$VCV)
autocorr.diag(modelMat$VCV)
effectiveSize(modelMat$VCV)
summary(modelMat)


# Heredabilidad ####
# Ecuacin 2
#proporcin de varianza gentica aditiva en la variacin fenotpica
# en caso de estimar heredabilidad + EM
mater <- modelMat$VCV[,"dam"]/(modelMat$VCV[,"animal"] +modelMat$VCV[,"dam"]+ modelMat$VCV[, "units"])
herit_mater <- modelMat$VCV[,"animal"]/(modelMat$VCV[,"animal"] +modelMat$VCV[,"dam"]+ modelMat$VCV[, "units"])

# estadstica descriptiva
effectiveSize(mater)
effectiveSize(herit_mater)

posterior.mode(mater)
posterior.mode(herit_mater)

HPDinterval(mater)
HPDinterval(herit_mater)



# en caso de estimar heredabilidad
herit <- modelMat$VCV[, "animal"]/(modelMat$VCV[, "animal"] + modelMat$VCV[, "units"])

# estadstica descriptiva
effectiveSize(herit)
posterior.mode(herit)
HPDinterval(herit)
