rm(list = ls())

library(dplyr)
library(tidyr)
library(MCMCglmm)
library(ggplot2)
library(gridExtra)


mMaternal <- list()
load(file = "./Mhijos.obj")
mMaternal[[1]] <- modelMat$VCV
load(file = "./Mlastkid.obj")
mMaternal[[2]]<- modelMat$VCV 
load(file = "./MrangeFert.obj")
mMaternal[[3]] <- modelMat$VCV 


Hered <- list()
for (i in 1:length(mMaternal)) {
Hered[[i]] <- mMaternal[[i]][,1]/(mMaternal[[i]][,1] +
                               mMaternal[[i]][,2] +
                               mMaternal[[i]][,3])
}
glimpse(Hered)

#nico rasgo sin efecto materno
load(file = "./Mfirstkid.obj")
Hered[[4]] <-modelMat$VCV[,1]/(modelMat$VCV[,1]+modelMat$VCV[,2])


Matern <- list()
for (i in 1:length(mMaternal)) {
  Matern[[i]] <- mMaternal[[i]][,2]/(mMaternal[[i]][,1] +
                                      mMaternal[[i]][,2] +
                                      mMaternal[[i]][,3])
}

glimpse(Matern)

resumenH <- list(sapply(Hered, posterior.mode),
                 sapply(Hered, min),
                 sapply(Hered, max),
                 sapply(Hered, HPDinterval))
glimpse(resumenH)
  
resumenHered <- data.frame(moda = resumenH[[1]],
                         minim = resumenH[[2]],
                         maxim = resumenH[[3]],
                         lower = resumenH[[4]][1,],
                         upper =resumenH[[4]][2,],
                         rasgo = c("n_hijos", "ult_hijo", "rango_Fert", "1er_hijo")
)
resumenHered$rasgo <- as.character(resumenHered$rasgo)
resumenHered$rasgo <- factor(resumenHered$rasgo, levels = unique(resumenHered$rasgo))

resumenM <- list(sapply(Matern, posterior.mode),
                 sapply(Matern, min),
                 sapply(Matern, max),
                 sapply(Matern, HPDinterval))
glimpse(resumenM)

resumenMat <- data.frame(moda = resumenM[[1]],
           minim = resumenM[[2]],
           maxim = resumenM[[3]],
           lower = resumenM[[4]][1,],
           upper =resumenM[[4]][2,],
           rasgo =  c("n_hijos", "ult_hijo", "rango_Fert")
)
resumenMat[4,1:5] <- c(0, 0, 0, 0, 0)

resumenMat$rasgo <- as.character(resumenMat$rasgo)
resumenMat[4,6] <- "1er_hijo"
resumenMat$rasgo <- factor(resumenMat$rasgo, levels = unique(resumenMat$rasgo))


plot1 <- ggplot(resumenHered, aes(x = rasgo, y = moda, ymin = minim, ymax = maxim)) + 
  geom_linerange(aes(ymin=lower, ymax=upper), size = 1.7,
                 alpha = 0.4, color = "dodgerblue4") + 
  geom_pointrange(aes(ymin= minim, ymax=maxim),
                  color = "cadetblue3", size = 0.7)+
  theme(axis.text.x=element_text(size=10), axis.title.x=element_text(size=12),
        axis.text.y=element_text(size=10), axis.title.y=element_text(size=12),
        legend.text=element_text(size=10)) +
  theme(panel.background = element_rect(fill = "white", colour = "grey50"))+
  coord_flip() + labs(title = "Heredabilidad")


plot2 <- ggplot(resumenMat, aes(x = rasgo, y = moda, ymin = minim, ymax = maxim)) + 
  geom_linerange(aes(ymin=lower, ymax=upper), size = 1.7,
                 alpha = 0.4, color = "dodgerblue4") + 
  geom_pointrange(aes(ymin= minim, ymax=maxim),
                  color = "cadetblue3", size = 0.7)+
  theme(axis.text.x=element_text(size=10), axis.title.x=element_text(size=12),
        axis.text.y=element_blank(), axis.title.y=element_blank(),
        legend.text=element_text(size=10)) +
  theme(panel.background = element_rect(fill = "white", colour = "grey50"))+
  coord_flip() + labs(title = "Efecto materno")


grid.arrange(plot1, plot2, ncol=2)

dev.off()

write.table(resumenHered, "resumenHeredfit.txt")
write.table(resumenMat, "resumenMatfit.txt")

