rm(list=ls()) 
library("MCMCglmm")

# Base de datos ####
Face_ped <- read.table("./Face_ped_all.txt") #pedigr
Face_data <- read.table("./Face_data_residScaled_phen_Mat.txt", sep="") #datos
Face_ped$dam <- as.factor(Face_ped$dam)
Face_ped$sire <- as.factor(Face_ped$sire)
Face_data$dam <- as.factor(Face_data$dam)
Face_data$animal <- as.factor(Face_data$animal)

# Probabilidad inicial uniforme
# con efecto materno (EM)
prior <- list(R = list(V=1, nu= 1), G = list(G1 = list(V=1, nu= 1), G2=list(V=1, nu=1)))
# sin efecto materno
priorA <- list(R = list(V=1, nu= 1), G = list(G1 = list(V=1, nu= 1)))


#modelo lineal generalizado mixto
# en caso de estimar heredabilidad 
    # random = ~ animal,
    # prior = priorA
# en caso de estimar heredabilidad + EM
    # random = ~ animal + dam,
    # prior = prior
modelMat <- MCMCglmm(GnaNa ~ 1 + male,                  
                       random = ~ animal + dam,         
                       family =  "gaussian",               
                       prior = prior,          
                       data = Face_data,                
                       nitt = 650000,                    
                       burnin = 2000,                   
                       thin = 500)                      

# guardar modelo
save(modelMat, file = "./MGnaNa.obj")
# checar el modelo
plot(modelMat$VCV)
autocorr.diag(modelMat$VCV)
effectiveSize(modelMat$VCV)
summary(modelMat)


# Heredabilidad ####
# Ecuacin 2
#proporcin de varianza gentica aditiva en la variacin fenotpica
mater <- modelMat$VCV[,"dam"]/(modelMat$VCV[,"animal"] +modelMat$VCV[,"dam"]+ modelMat$VCV[, "units"])
herit <- modelMat$VCV[,"animal"]/(modelMat$VCV[,"animal"] +modelMat$VCV[,"dam"]+ modelMat$VCV[, "units"])

# estadstica descriptiva
effectiveSize(herit)
effectiveSize(mater)

posterior.mode(herit)
posterior.mode(mater)

HPDinterval(herit)
HPDinterval(mater)
