rm(list = ls())

library(dplyr)
library(tidyr)
library(MCMCglmm)
library(ggplot2)
library(gridExtra)

mMaternal <- list()
load(file = "./Mtalla.obj")
mMaternal[[1]] <- modelMat$VCV
load(file = "./MBigo.obj")
mMaternal[[2]]<- modelMat$VCV 
load(file = "./MBizig.obj")
mMaternal[[3]] <- modelMat$VCV 
load(file = "./MGnaNa.obj")
mMaternal[[4]] <- modelMat$VCV
load(file = "./MGnaGo.obj")
mMaternal[[5]] <- modelMat$VCV
load(file = "./MBitra.obj")
mMaternal[[6]] <- modelMat$VCV


Hered <- list()
for (i in 1:length(mMaternal)) {
Hered[[i]] <- mMaternal[[i]][,1]/(mMaternal[[i]][,1] +
                               mMaternal[[i]][,2] +
                               mMaternal[[i]][,3])
}
glimpse(Hered)

Matern <- list()
for (i in 1:length(mMaternal)) {
  Matern[[i]] <- mMaternal[[i]][,2]/(mMaternal[[i]][,1] +
                                      mMaternal[[i]][,2] +
                                      mMaternal[[i]][,3])
}

glimpse(Matern)

resumenH <- list(sapply(Hered, posterior.mode),
                 sapply(Hered, min),
                 sapply(Hered, max),
                 sapply(Hered, HPDinterval))
glimpse(resumenH)
resumenHered <- data.frame(moda = resumenH[[1]],
                         minim = resumenH[[2]],
                         maxim = resumenH[[3]],
                         lower = resumenH[[4]][1,],
                         upper =resumenH[[4]][2,],
                         rasgo = c("talla", "Bigo", "Bizig", "GnaNa", "GnaGo", "Bitra")
)
resumenHered$rasgo <- as.character(resumenHered$rasgo)
resumenHered$rasgo <- factor(resumenHered$rasgo, levels = unique(resumenHered$rasgo))

resumenM <- list(sapply(Matern, posterior.mode),
                 sapply(Matern, min),
                 sapply(Matern, max),
                 sapply(Matern, HPDinterval))
glimpse(resumenM)
resumenMat <- data.frame(moda = resumenM[[1]],
           minim = resumenM[[2]],
           maxim = resumenM[[3]],
           lower = resumenM[[4]][1,],
           upper =resumenM[[4]][2,],
           rasgo = c("talla", "Bigo", "Bizig", "GnaNa", "GnaGo", "Bitra")
)

resumenMat$rasgo <- as.character(resumenMat$rasgo)
resumenMat$rasgo <- factor(resumenMat$rasgo, levels = unique(resumenMat$rasgo))


plot1 <- ggplot(resumenHered, aes(x = rasgo, y = moda, ymin = minim, ymax = maxim)) + 
  geom_linerange(aes(ymin=lower, ymax=upper), size = 1.7,
                 alpha = 0.4, color = "dodgerblue4") + 
  geom_pointrange(aes(ymin= minim, ymax=maxim),
                  color = "cadetblue3", size = 0.7)+
  theme(axis.text.x=element_text(size=10), axis.title.x=element_text(size=12),
        axis.text.y=element_text(size=10), axis.title.y=element_text(size=12),
        legend.text=element_text(size=10)) +
  theme(panel.background = element_rect(fill = "white", colour = "grey50"))+
  coord_flip() + labs(title = "Heredabilidad")


plot2 <- ggplot(resumenMat, aes(x = rasgo, y = moda, ymin = minim, ymax = maxim)) + 
  geom_linerange(aes(ymin=lower, ymax=upper), size = 1.7,
                 alpha = 0.4, color = "dodgerblue4") + 
  geom_pointrange(aes(ymin= minim, ymax=maxim),
                  color = "cadetblue3", size = 0.7)+
  theme(axis.text.x=element_text(size=10), axis.title.x=element_text(size=12),
        axis.text.y=element_blank(), axis.title.y=element_blank(),
        legend.text=element_text(size=10)) +
  theme(panel.background = element_rect(fill = "white", colour = "grey50"))+
  coord_flip() + labs(title = "Efecto materno")

grid.arrange(plot1, plot2, ncol=2)


dev.off()



write.table(resumenHered, "resumenHeredPhen.txt")
write.table(resumenMat, "resumenMatPhen.txt")
